import React, { useContext, useEffect } from 'react';
import { View } from 'react-native';
import Skin from './components/skin';
import Body from './components/body';
import FacialHair from './components/facial-hair';
import Eyes from './components/eyes';
import Hair from './components/hair';
import Mouth from './components/mouth';
import Nose from './components/nose';
import { AvatarController, AvatarContext } from './context';
import { backgroundColors } from './constants/background';
import { facialHairColors, facialHairs } from './constants/facial-hair';
import { hairColors, hairs } from './constants/hair';
import { bodyColors, bodies } from './constants/body';
import { skinColors } from './constants/skin';
import { random, combineCharacters, parseCharacters } from './utils';
import { eyeses } from './constants/eyes';
import mouths from './constants/mouth';
import noses from './constants/nose';
function PersonasAvatar({ style, characters, onNewCharacters }) {
    const [state, dispatch] = useContext(AvatarContext);
    const { skinColor, hair, hairColor, body, bodyColor, facialHair, facialHairColor, eyes, mouth, nose, backgroundColor, } = state;
    useEffect(() => {
        if (!characters) {
            randomAvatar();
        }
        else {
            const components = parseCharacters(characters);
            dispatch({ type: 'updateCharacters', payload: components });
        }
    }, [characters]);
    function randomAvatar() {
        const randomCharacters = {
            skinColor: random(Object.keys(skinColors)),
            hair: random(Object.keys(hairs)),
            hairColor: random(Object.keys(hairColors)),
            facialHair: random(Object.keys(facialHairs)),
            facialHairColor: random(Object.keys(facialHairColors)),
            body: random(Object.keys(bodies)),
            bodyColor: random(Object.keys(bodyColors)),
            eyes: random(Object.keys(eyeses)),
            mouth: random(Object.keys(mouths)),
            nose: random(Object.keys(noses)),
            backgroundColor: random(Object.keys(backgroundColors)),
        };
        const characters = combineCharacters(randomCharacters);
        if (onNewCharacters) {
            onNewCharacters(characters);
        }
        dispatch({ type: 'updateCharacters', payload: randomCharacters });
    }
    return (React.createElement(View, { style: [
            {
                width: 200,
                height: 200,
                borderRadius: 1000,
                overflow: 'hidden',
                backgroundColor: backgroundColors[backgroundColor],
            },
            style,
        ] },
        React.createElement(Body, { value: body, color: bodyColors[bodyColor] }),
        React.createElement(Skin, { color: skinColors[skinColor] }),
        React.createElement(Hair, { value: hair, color: hairColors[hairColor] }),
        React.createElement(Eyes, { value: eyes }),
        React.createElement(Mouth, { value: mouth }),
        React.createElement(FacialHair, { value: facialHair, color: facialHairColors[facialHairColor] }),
        React.createElement(Nose, { value: nose, color: skinColors[skinColor] })));
}
export default function (props) {
    return (React.createElement(AvatarController, null,
        React.createElement(PersonasAvatar, Object.assign({}, props))));
}
//# sourceMappingURL=personas-avatar.js.map